function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var colors = require('@material-ui/core/colors');
var Radio = _interopDefault(require('@material-ui/core/Radio'));
var Slider = _interopDefault(require('@material-ui/core/Slider'));
var styles$1 = require('@material-ui/core/styles');
var Tooltip = _interopDefault(require('@material-ui/core/Tooltip'));
var Typography = _interopDefault(require('@material-ui/core/Typography'));
var CheckIcon = _interopDefault(require('@material-ui/icons/Check'));
var PropTypes = _interopDefault(require('prop-types'));
var React = _interopDefault(require('react'));

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it;

  if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) {
    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;
      return function () {
        if (i >= o.length) return {
          done: true
        };
        return {
          done: false,
          value: o[i++]
        };
      };
    }

    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  it = o[Symbol.iterator]();
  return it.next.bind(it);
}

var defaultColor = '#2196f3';
var hues = Object.keys(colors).slice(1, 17);
var shades = [900, 800, 700, 'A700', 600, 500, 400, 'A400', 300, 200, 'A200', 100, 'A100', 50];

var styles = function styles(theme) {
  return {
    radio: {
      padding: 0
    },
    radioIcon: {
      width: 48,
      height: 48
    },
    radioIconSelectedWhite: {
      width: 48,
      height: 48,
      color: theme.palette.common.white,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    },
    radioIconSelectedBlack: {
      width: 48,
      height: 48,
      display: 'flex',
      justifyContent: 'center',
      alignItems: 'center'
    },
    swatch: {
      width: 192
    },
    sliderContainer: {
      width: 192,
      display: 'flex',
      alignItems: 'center',
      marginTop: theme.spacing(2),
      marginBottom: theme.spacing(2)
    },
    slider: {
      width: 'calc(100% - 40px)',
      marginLeft: theme.spacing(2),
      marginRight: theme.spacing(1)
    }
  };
};

var colorToHueShadeMap = null;

var buildColorToHueShadeMap = function buildColorToHueShadeMap() {
  if (!colorToHueShadeMap) {
    colorToHueShadeMap = {};

    for (var _iterator = _createForOfIteratorHelperLoose(hues), _step; !(_step = _iterator()).done;) {
      var hue = _step.value;
      var shadeIndex = 0;

      for (var _iterator2 = _createForOfIteratorHelperLoose(shades), _step2; !(_step2 = _iterator2()).done;) {
        var shade = _step2.value;
        var color = colors[hue][shade];
        colorToHueShadeMap[color] = {
          hue: hue,
          shadeIndex: shadeIndex
        };
        shadeIndex++;
      }
    }
  }
};

function hueFromColor(color) {
  buildColorToHueShadeMap();
  var hueShade = colorToHueShadeMap[color];
  return hueShade ? hueShade.hue : 'blue';
}

function shadeFromColor(color) {
  buildColorToHueShadeMap();
  var hueShade = colorToHueShadeMap[color];
  return hueShade ? hueShade.shadeIndex : 5;
}

function PrimaryColorPicker(props) {
  var classes = props.classes;

  var _React$useState = React.useState(hueFromColor(props.defaultColor ? props.defaultColor : defaultColor)),
      selectedHue = _React$useState[0],
      setSelectedHue = _React$useState[1];

  var _React$useState2 = React.useState(shadeFromColor(props.defaultColor ? props.defaultColor : defaultColor)),
      selectedShadeIndex = _React$useState2[0],
      setSelectedShadeIndex = _React$useState2[1];

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: classes.sliderContainer
  }, /*#__PURE__*/React.createElement(Typography, {
    id: 'ShadeSliderLabel'
  }, "Shade:"), /*#__PURE__*/React.createElement(Slider, {
    className: classes.slider,
    value: selectedShadeIndex,
    min: 0,
    max: 13,
    step: 1,
    onChange: function onChange(e, shadeIndex) {
      props.onChange(colors[selectedHue][shades[shadeIndex]]);
      setSelectedShadeIndex(shadeIndex);
    },
    "aria-labelledby": 'ShadeSliderLabel'
  })), /*#__PURE__*/React.createElement("div", {
    className: classes.swatch
  }, hues.map(function (hue) {
    var backgroundColor = colors[hue][shades[selectedShadeIndex]];
    return /*#__PURE__*/React.createElement(Tooltip, {
      placement: "right",
      title: hue,
      key: hue
    }, /*#__PURE__*/React.createElement(Radio, {
      className: classes.radio,
      color: "default",
      checked: colors[selectedHue][shades[selectedShadeIndex]] === backgroundColor,
      "data-testid": hue,
      onChange: function onChange(e) {
        props.onChange(colors[e.target.value][shades[selectedShadeIndex]]);
        setSelectedHue(e.target.value);
      },
      value: hue,
      "aria-labelledby": "tooltip-" + hue,
      icon: /*#__PURE__*/React.createElement("div", {
        className: classes.radioIcon,
        style: {
          backgroundColor: backgroundColor
        }
      }),
      checkedIcon: /*#__PURE__*/React.createElement("div", {
        className: selectedShadeIndex >= 6 && selectedShadeIndex <= 9 || selectedShadeIndex === 13 ? classes.radioIconSelectedBlack : classes.radioIconSelectedWhite,
        style: {
          backgroundColor: backgroundColor
        }
      }, /*#__PURE__*/React.createElement(CheckIcon, {
        style: {
          fontSize: 30
        }
      }))
    }));
  })));
}

PrimaryColorPicker.propTypes = {
  classes: PropTypes.object.isRequired,
  onChange: PropTypes.func.isRequired
};
var index = styles$1.withStyles(styles)(PrimaryColorPicker);

module.exports = index;
//# sourceMappingURL=index.js.map
